Class: SmileIdentityCore::AmlCheck

Inherits:
Object
  • Object
show all
Includes:
Validations
Defined in:
lib/smile-identity-core/aml_check.rb

Overview

The AML Check product allows you to perform due diligence on your customers by screening them against global watchlists, politically exposed persons lists, and adverse media publications. For more info visit docs.usesmileid.com/products/for-individuals-kyc/aml-check

Instance Method Summary collapse

Methods included from Validations

#validate_id_info, #validate_partner_params

Constructor Details

#initialize(partner_id, api_key, sid_server) ⇒ AmlCheck

Submit AML

Parameters:

  • :partner_id (String)

    A unique number assigned by Smile ID to your account. Can be found in the portal

  • :api_key (String)

    your API key from the Smile Identity portal

  • :sid_server (String)

    Use 0 for the sandbox server, use 1 for production server



20
21
22
23
24
25
# File 'lib/smile-identity-core/aml_check.rb', line 20

def initialize(partner_id, api_key, sid_server)
  @api_key = api_key
  @partner_id = partner_id.to_s
  @sid_server = sid_server
  @url = SmileIdentityCore::ENV.determine_url(sid_server)
end

Instance Method Details

#submit_job(params) ⇒ Object

Submit AML (ISO 3166-1 alpha-2) format e.g. Nigeria is NG, Kenya is KE, etc of a user’s previous KYC job in partner_params.

Parameters:

  • params (Hash)

    the options to create a job with.

  • opts (Hash)

    a customizable set of options



42
43
44
45
46
# File 'lib/smile-identity-core/aml_check.rb', line 42

def submit_job(params)
  @params = symbolize_keys(params)
  @optional_info = @params[:optional_info]
  submit_requests
end